@@ -154,7 +154,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -170,13 +170,13 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_apigateway
-import aws_cdk.aws_wafv2
-import constructs
+import aws_cdk.aws_apigateway as _aws_cdk_aws_apigateway_ceddda9d
+import aws_cdk.aws_wafv2 as _aws_cdk_aws_wafv2_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class WafwebaclToApiGateway(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-wafwebacl-apigateway.WafwebaclToApiGateway",
 ):
@@ -186,12 +186,12 @@ class WafwebaclToApiGateway(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        existing_api_gateway_interface: aws_cdk.aws_apigateway.IRestApi,
-        existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
-        webacl_props: typing.Optional[typing.Union[aws_cdk.aws_wafv2.CfnWebACLProps, typing.Dict[str, typing.Any]]] = None,
+        existing_api_gateway_interface: _aws_cdk_aws_apigateway_ceddda9d.IRestApi,
+        existing_webacl_obj: typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACL] = None,
+        webacl_props: typing.Optional[typing.Union[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -204,16 +204,7 @@ class WafwebaclToApiGateway(
         :summary: Constructs a new instance of the WafwebaclToApiGateway class.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                existing_api_gateway_interface: aws_cdk.aws_apigateway.IRestApi,
-                existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
-                webacl_props: typing.Optional[typing.Union[aws_cdk.aws_wafv2.CfnWebACLProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__df51618df3f45a67084046954140a8d196b65d7e3415d21e53bf312dac4dff1e)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = WafwebaclToApiGatewayProps(
@@ -226,13 +217,13 @@ class WafwebaclToApiGateway(
 
     @builtins.property
     @jsii.member(jsii_name="apiGateway")
-    def api_gateway(self) -> aws_cdk.aws_apigateway.IRestApi:
-        return typing.cast(aws_cdk.aws_apigateway.IRestApi, jsii.get(self, "apiGateway"))
+    def api_gateway(self) -> _aws_cdk_aws_apigateway_ceddda9d.IRestApi:
+        return typing.cast(_aws_cdk_aws_apigateway_ceddda9d.IRestApi, jsii.get(self, "apiGateway"))
 
     @builtins.property
     @jsii.member(jsii_name="webacl")
-    def webacl(self) -> aws_cdk.aws_wafv2.CfnWebACL:
-        return typing.cast(aws_cdk.aws_wafv2.CfnWebACL, jsii.get(self, "webacl"))
+    def webacl(self) -> _aws_cdk_aws_wafv2_ceddda9d.CfnWebACL:
+        return typing.cast(_aws_cdk_aws_wafv2_ceddda9d.CfnWebACL, jsii.get(self, "webacl"))
 
 
 @jsii.data_type(
@@ -248,9 +239,9 @@ class WafwebaclToApiGatewayProps:
     def __init__(
         self,
         *,
-        existing_api_gateway_interface: aws_cdk.aws_apigateway.IRestApi,
-        existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
-        webacl_props: typing.Optional[typing.Union[aws_cdk.aws_wafv2.CfnWebACLProps, typing.Dict[str, typing.Any]]] = None,
+        existing_api_gateway_interface: _aws_cdk_aws_apigateway_ceddda9d.IRestApi,
+        existing_webacl_obj: typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACL] = None,
+        webacl_props: typing.Optional[typing.Union[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param existing_api_gateway_interface: The existing API Gateway instance that will be protected with the WAF web ACL.
@@ -260,20 +251,13 @@ class WafwebaclToApiGatewayProps:
         :summary: The properties for the WafwebaclToApiGateway class.
         '''
         if isinstance(webacl_props, dict):
-            webacl_props = aws_cdk.aws_wafv2.CfnWebACLProps(**webacl_props)
+            webacl_props = _aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps(**webacl_props)
         if __debug__:
-            def stub(
-                *,
-                existing_api_gateway_interface: aws_cdk.aws_apigateway.IRestApi,
-                existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
-                webacl_props: typing.Optional[typing.Union[aws_cdk.aws_wafv2.CfnWebACLProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__dfbe360f3b43d03604a94c0bddbc22c38e3fca02ac15bb330f1f32c36bf61ae1)
             check_type(argname="argument existing_api_gateway_interface", value=existing_api_gateway_interface, expected_type=type_hints["existing_api_gateway_interface"])
             check_type(argname="argument existing_webacl_obj", value=existing_webacl_obj, expected_type=type_hints["existing_webacl_obj"])
             check_type(argname="argument webacl_props", value=webacl_props, expected_type=type_hints["webacl_props"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "existing_api_gateway_interface": existing_api_gateway_interface,
         }
         if existing_webacl_obj is not None:
@@ -282,26 +266,32 @@ class WafwebaclToApiGatewayProps:
             self._values["webacl_props"] = webacl_props
 
     @builtins.property
-    def existing_api_gateway_interface(self) -> aws_cdk.aws_apigateway.IRestApi:
+    def existing_api_gateway_interface(
+        self,
+    ) -> _aws_cdk_aws_apigateway_ceddda9d.IRestApi:
         '''The existing API Gateway instance that will be protected with the WAF web ACL.'''
         result = self._values.get("existing_api_gateway_interface")
         assert result is not None, "Required property 'existing_api_gateway_interface' is missing"
-        return typing.cast(aws_cdk.aws_apigateway.IRestApi, result)
+        return typing.cast(_aws_cdk_aws_apigateway_ceddda9d.IRestApi, result)
 
     @builtins.property
-    def existing_webacl_obj(self) -> typing.Optional[aws_cdk.aws_wafv2.CfnWebACL]:
+    def existing_webacl_obj(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACL]:
         '''Existing instance of a WAF web ACL, an error will occur if this and props is set.'''
         result = self._values.get("existing_webacl_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_wafv2.CfnWebACL], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACL], result)
 
     @builtins.property
-    def webacl_props(self) -> typing.Optional[aws_cdk.aws_wafv2.CfnWebACLProps]:
+    def webacl_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps]:
         '''Optional user-provided props to override the default props for the AWS WAF web ACL.
 
         :default: - Default properties are used.
         '''
         result = self._values.get("webacl_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_wafv2.CfnWebACLProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -321,3 +311,23 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__df51618df3f45a67084046954140a8d196b65d7e3415d21e53bf312dac4dff1e(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    existing_api_gateway_interface: _aws_cdk_aws_apigateway_ceddda9d.IRestApi,
+    existing_webacl_obj: typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACL] = None,
+    webacl_props: typing.Optional[typing.Union[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__dfbe360f3b43d03604a94c0bddbc22c38e3fca02ac15bb330f1f32c36bf61ae1(
+    *,
+    existing_api_gateway_interface: _aws_cdk_aws_apigateway_ceddda9d.IRestApi,
+    existing_webacl_obj: typing.Optional[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACL] = None,
+    webacl_props: typing.Optional[typing.Union[_aws_cdk_aws_wafv2_ceddda9d.CfnWebACLProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
